@@ -567,11 +567,11 @@ track_free (Track *track, gpointer user_data)
 {
 	switch (track->type) {
 	case TRACK_TYPE_DATA:
-		g_free (track->data.filename);
+		g_free (track->contents.data.filename);
 		break;
 	case TRACK_TYPE_AUDIO:
-		g_free (track->audio.filename);
-		g_free (track->audio.cdtext);
+		g_free (track->contents.audio.filename);
+		g_free (track->contents.audio.cdtext);
 		break;
 	default:
 		g_warning ("Invalid track type %d", track->type);
@@ -646,6 +646,9 @@ file_chooser_response_cb (GtkWidget *chooser, gint response, gpointer data)
 
 	file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
 
+	if (!file_name)
+		return;
+
 	if (strlen (file_name) < 1) {
 		g_free (file_name);
 		return;
@@ -846,7 +849,7 @@ burn_cd (CDDrive *rec, const char *source_iso, const char *label, gboolean eject
 			Track *track;
 			track = g_new0 (Track, 1);
 			track->type = TRACK_TYPE_DATA;
-			track->data.filename = g_strdup (filename);
+			track->contents.data.filename = g_strdup (filename);
 			tracks = g_list_prepend (tracks, track);
 		}
 		res = cd_recorder_write_tracks (cdrecorder, rec, tracks, speed, eject_cd, blank_cd, dummy, FALSE);
